__version__ = '0.1.0'
import spacy
from collections import Counter
import json
import subprocess
#need to install as follows: python -m spacy download en_core_web_sm


moral_foundations_dictionary = {'care': {'virtue': ['compassion', 'empathy', 'kindness', 'caring', 'generosity', 'benevolence', 'altruism', 'compassionate', 'nurture', 'gentleness', 'nurturance', 'sympathy', 'nurturing', 'motherly', 'love', 'beneficence', 'empathize', 'helpfulness', 'loving', 'pity', 'mercy', 'nurturer', 'compassionately', 'nurturers', 'caringly', 'empathising', 'merciful', 'empathizing', 'nurtures', 'warmhearted', 'empathizers', 'protectiveness', 'nurtured', 'benevolent', 'mothering', 'cared', 'healing', 'empathises', 'humane', 'comfort', 'pitied', 'loved', 'altruist', 'cares', 'pitying', 'comforted', 'hug', 'comforting', 'consoling', 'empathizes', 'sympathize', 'care', 'caregiver', 'empathised', 'hugs', 'heal', 'generous', 'condolences', 'mothered', 'charitable', 'generously', 'pities', 'condolence', 'help', 'consolingly', 'solace', 'mother', 'healer', 'hospitality', 'charity', 'empathized', 'healers', 'pityingly', 'mothers', 'child', 'lovingly', 'parenting', 'rescuing', 'rescuer', 'loves', 'consoled', 'clothe', 'sympathizing', 'helping', 'shared', 'childhood', 'mommy', 'helpers', 'lover', 'hospitable', 'sharer', 'feeding', 'nursed', 'helper', 'safeness', 'nurses', 'motherhood', 'alleviation', 'nursemaid', 'safeguard', 'healthiness', 'protecters', 'patient', 'nurse', 'benefit', 'feed', 'childcare', 'rescuers', 'hugged', 'helpful', 'rescues', 'nursing', 'heals', 'childbearing', 'hugger', 'relief', 'healed', 'rescued', 'patients', 'share', 'rescue', 'healthy', 'hospitalise', 'hospitalising', 'hugging', 'nursery', 'healthier', 'sharing', 'helps', 'sympathizers', 'hospitalises', 'alleviating', 'hospitalize', 'alleviate', 'protective', 'health', 'relieve', 'sympathizer', 'safety', 'beneficiary', 'helped', 'hospital', 'childbirth', 'benefits', 'healthcare', 'relievers', 'feeds', 'hospitalization', 'benefitting', 'relieving', 'safe', 'feeder', 'benefitted', 'hospitalized', 'unharmful', 'unharmed', 'protecter', 'safely', 'safekeeping', 'hospitalizing', 'reliever', 'shares', 'relieves', 'alleviates', 'relieved', 'hospitalizes', 'console', 'protectorate', 'alleviated', 'consoles'], 'vice': ['vulnerability', 'vulnerable', 'wounded', 'wounds', 'wounding', 'wound', 'harm', 'suffer', 'hurt', 'harmed', 'hurting', 'hurts', 'cruel', 'endanger', 'harming', 'harms', 'suffering', 'threaten', 'inflict', 'suffered', 'harmful', 'inflicted', 'mistreat', 'endangers', 'damaging', 'injurious', 'victimize', 'inflicts', 'hurtful', 'suffers', 'inflicting', 'injures', 'unkind', 'damage', 'kill', 'die', 'victimizes', 'torment', 'destroy', 'brutalise', 'brutalises', 'distresses', 'endangering', 'mistreats', 'afflict', 'distressing', 'destroys', 'victimises', 'maltreat', 'pain', 'harsh', 'mistreated', 'ravage', 'threatened', 'harass', 'unkindness', 'afflicted', 'threatens', 'threatening', 'distress', 'brutalize', 'tormenting', 'brutalized', 'victimizing', 'damager', 'damaged', 'agony', 'abused', 'coldhearted', 'inhuman', 'injured', 'torments', 'brutalizes', 'uncompassionate', 'cruelty', 'tormented', 'mistreating', 'endangered', 'uncaring', 'anguishes', 'destroying', 'killed', 'mistreatment', 'harsher', 'cruelness', 'tortured', 'pained', 'tortures', 'torturing', 'maltreated', 'anguish', 'persecutes', 'maltreatment', 'brutalizing', 'attacked', 'victim', 'crying', 'damages', 'discomforting', 'abusing', 'threat', 'persecute', 'brutalization', 'violent', 'annihilated', 'torturous', 'harasses', 'injurer', 'destroyed', 'molests', 'molest', 'injuring', 'afflicts', 'killing', 'ache', 'persecuted', 'ravages', 'harassed', 'injury', 'brutalisation', 'discomfort', 'unmerciful', 'annihilate', 'injurers', 'destruction', 'manhandle', 'kills', 'casualties', 'maltreating', 'victims', 'harassing', 'needier', 'smother', 'harassment', 'smothers', 'unhelpful', 'agonize', 'inhumanity', 'duress', 'victimization', 'cried', 'murderous', 'ravaged', 'uncaringly', 'pains', 'painfulness', 'manhandles', 'assaulted', 'uncharitable', 'distressed', 'persecution', 'murdered', 'ravaging', 'discomforted', 'torture', 'murderers', 'aches', 'afflictions', 'ungenerous', 'victimizer', 'agonizing', 'paining', 'persecuting', 'harassers', 'malevolent', 'stabs', 'sorrowful', 'assaults', 'needy', 'affliction', 'cries', 'fighting', 'fight', 'attack', 'annihilates', 'sorrow', 'agonized', 'assaulting', 'inhospitable', 'threats', 'ached', 'rapists', 'abuser', 'raped', 'assassinates', 'stabbed', 'inhospitality', 'annihilation', 'punch', 'harshness', 'abusers', 'killer', 'sufferers', 'victimizers', 'smite', 'killers', 'discomforts', 'fatalities', 'molested', 'brutality', 'murdering', 'torturer', 'torturers', 'fights', 'harmfulness', 'casualty', 'sufferer', 'fatality', 'punches', 'abuses', 'attacks', 'carnage', 'tribulation', 'annihilator', 'smothering', 'bullyboy', 'murderer', 'stabber', 'tormenters', 'malevolence', 'raping', 'smothered', 'assault', 'genocidal', 'anguishing', 'aching', 'anguished', 'stabbing', 'rapist', 'harasser', 'hungers', 'hunger', 'molesting', 'rape', 'molesters', 'punched', 'violence', 'distressingly', 'molester', 'stabbers', 'neediness', 'assassinate', 'agonizingly', 'tribulations', 'unhelpfulness', 'assaulter', 'puncher', 'punching', 'rapes', 'genocides', 'attackers', 'tormentor', 'assassinations', 'destroyers', 'punchers', 'sorrows', 'tormenter', 'threateningly', 'murder', 'destroyer', 'assassinating', 'crier', 'assassinated', 'molestation', 'attacker', 'murders', 'genocide', 'fighter', 'assassins', 'assaulters', 'hungering', 'achingly', 'hungered', 'murderess', 'assassin', 'fighters', 'assassination']}, 'fairness': {'virtue': ['equality', 'fairness', 'justice', 'rights', 'equitable', 'civil rights', 'fairplay', 'impartiality', 'equal', 'fairminded', 'proportionality', 'equalities', 'fair', 'integrity', 'impartial', 'reciprocity', 'honesty', 'egalitarian', 'civil right', 'law', 'justness', 'unbias', 'egalitarians', 'parity', 'objectiveness', 'reparations', 'unprejudiced', 'justices', 'laws', 'tribunals', 'retribution', 'reparation', 'lawfully', 'lawful', 'honest', 'compensation', 'lawyers', 'sportsmanship', 'tribunal', 'do unto others', 'golden rule', 'lawyer', 'proportional', 'equity', 'lawyering', 'trust', 'reciprocal', 'being objective', 'justification', 'trustworthiness', 'unbiased', 'vengeance', 'revenge', 'retributions', 'equals', 'equalize', 'refereeing', 'restitution', 'compensating', 'been objective', 'pay back', 'justified', 'justifies', 'retaliation', 'lawyered', 'compensated', 'referees', 'karma', 'will share', 'avenger', 'trusting', 'avengers', 'square deal', 'trusts', 'compensate', 'trustworthy', 'levels the playing field', 'tit for tat', 'retaliate', 'level the playing field', 'eye for an eye', 'square deals', 'repayment', 'payback', 'equities', 'justify', 'dues', 'square dealing', 'referee', 'repaid', 'square dealer', 'equalizer', 'due processes', 'level playing fields', 'repay', 'compensates', 'justifying', 'due processing', 'due process', 'repayments', 'repaying', 'level playing field', 'retaliating', 'square dealers', 'retaliated', 'refereed', 'revenger', 'avenging', 'repays', 'trusted', 'avenge', 'retaliates', 'equalizers', 'avenged', 'avenges'], 'vice': ['exploited', 'exploiters', 'exploiting', 'exploitation', 'exploit', 'exploiter', 'exploits', 'cheat', 'unfair', 'cheating', 'unfairness', 'injustice', 'fraud', 'dishonest', 'unjust', 'cheated', 'fraudulent', 'cheats', 'frauds', 'dishonesty', 'cheaters', 'deception', 'injustices', 'swindle', 'inequity', 'hypocrisy', 'discrimination', 'unequal', 'cheater', 'inequities', 'defraud', 'racism', 'scam', 'liar', 'defrauds', 'betrayal', 'deceipt', 'defrauded', 'inequality', 'liars', 'defrauders', 'hypocrite', 'biased', 'ripoffs', 'scams', 'fleecing', 'defrauder', 'discriminates', 'mislead', 'inequalities', 'prejudice', 'fleeced', 'defrauding', 'ripoff', 'scamming', 'imposters', 'crooked', 'racist', 'oppression', 'imposter', 'swindled', 'hypocrites', 'plagiarism', 'lied', 'untrustworthiness', 'hoodwink', 'scammed', 'blackmail', 'bilks', 'swindling', 'bias', 'connive', 'crooks', 'deceive', 'freeloaders', 'favoritism', 'disparity', 'swindles', 'deceived', 'misleading', 'discriminated', 'bilked', 'deceiving', 'untrustworthy', 'prejudiced', 'false advertise', 'scammers', 'swindler', 'theft', 'duplicitous', 'hoodwinked', 'bigoted', 'sexism', 'disproportionate', 'swindlers', 'discriminate', 'conniving', 'sexist', 'hoodwinking', 'partiality', 'misleads', 'disproportion', 'economic disparity', 'bilk', 'biases', 'bigots', 'distrust', 'dupe', 'crook', 'racists', 'con artist', 'bilking', 'blackmailing', 'deceives', 'deceiver', 'blackmailed', 'duping', 'shyster', 'connivers', 'imbalanced', 'con artists', 'sexists', 'thieving', 'imbalance', 'disproportions', 'disproportionately', 'freeloader', 'misleaders', 'connived', 'shysters', 'scammer', 'connives', 'conniver', 'disadvantaged', 'plagiaristic', 'moocher', 'dupes', 'discriminating', 'tricked', 'segregation', 'false advertised', 'thief', 'bigot', 'lying', 'thieves', 'stealing', 'suckered', 'deceivers', 'bamboozled', 'false advertisement', 'freeload', 'bamboozle', 'did rob', 'freeloading', 'steal', 'pickpocketing', 'blackmailer', 'prejudicing', 'chauvinists', 'misleader', 'hoodwinks', 'false advertiser', 'imbalances', 'pickpocketed', 'pickpockets', 'bamboozles', 'tricking', 'taking advantage', 'pickpocket', 'false advertisers', 'biasing', 'false impression', 'bamboozling', 'false witness', 'robs', 'moochers', 'robbing', 'false advertises', 'false impressions', 'blackmails', 'double cross', 'blackmailers', 'will rob', 'stolen', 'distrustful', 'false advertising', 'double crossers', 'mooches', 'disproportioned', 'mooching', 'segregated', 'double crosser', 'robbed', 'misleadingly', 'segregating', 'stole', 'double crosses', 'being partial', 'distrusts', 'mooch', 'segregate', 'robbers', 'distrusted', 'double crossing', 'distrusting', 'double crossed', 'be partial', 'go back on', 'stacking the deck', 'robber', 'segregates', 'ripping off', 'trickster', 'rips off', 'behind their backs', 'mooched', 'stacked the deck', 'was partial', 'am partial', 'stacked deck', 'stacks the deck', 'behind their back', 'been partial', 'free rider', 'ripped off', 'free riders', 'deceivingly', 'steals', 'unequaled']}, 'loyalty': {'virtue': ['team player', 'player', 'patriot', 'loyal', 'loyalty', 'patriots', 'follower', 'fidelity', 'ally', 'comrade', 'loyalties', 'death do us part', 'faction', 'comrades', 'sacrifice', 'allies', 'organization', 'followers', 'us against them', 'sacrifices', 'all for one', 'comradery', 'one for all', 'fellow', 'family', 'corps', 'unity', 'union jack', 'uniter', 'old glory', 'companions', 'country', 'companion', 'homeland', 'sacrificing', 'indivisible', 'sacrificed', 'solidarity', 'troops', 'nation', 'cult', 'kinship', 'companionship', 'clique', 'allied', 'community', 'group', 'factions', 'familiarity', 'solidarities', 'enlist', 'companionships', 'wife', 'united', 'belongs', 'congregation', 'brothers in arms', 'clan', 'trooper', 'sect', 'enlisted', 'enlistment', 'tribalism', 'cohorts', 'war', 'joining', 'troop', 'sacrificial', 'coalition', 'insider', 'pledge', 'cohort', 'enlisting', 'unite', 'familiarities', 'belong', 'ingroup', 'belonged', 'company', 'collective', 'fellows', 'cliques', 'uniting', 'clans', 'hazing', 'congregates', 'herd', 'sects', 'uniters', 'undivided', 'unites', 'pledgers', 'coalitions', 'enlists', 'grouping', 'insiders', 'families', 'troupe', 'fellowship', 'kin', 'pledger', 'horde', 'nations', 'tribe', 'hordes', 'pledges', 'herder', 'commune', 'cults', 'congregations', 'organizations', 'herds', 'pledging', 'communities', 'familiar', 'hazings', 'belonging', 'pledged', 'collectively', 'together', 'groups', 'homelands', 'collectives', 'troopers', 'tribes', 'companies', 'countries', 'troupes', 'fellowships', 'tribal', 'communes', 'herders', 'grouped', 'herding', 'congregate', 'herded', 'congregating'], 'vice': ['betrayed', 'betraying', 'betrayers', 'betray', 'betrayer', 'betrays', 'disloyal', 'unpatriotic', 'enemies', 'backstabber', 'backstabbed', 'enemy', 'deserter', 'infidels', 'infidel', 'backstab', 'deserting', 'backstabbers', 'unfaithful', 'desertion', 'deserters', 'unfaithfulness', 'backstabbing', 'cheat on', 'backstabs', 'outsider', 'outgroup', 'cheated on', 'against us', 'cheating on', 'infidelity', 'outgroups', 'outsiders', 'cheats on']}, 'authority': {'virtue': ['protector', 'protect', 'protecting', 'protection', 'protects', 'protected', 'bully', 'bullied', 'bullies', 'bullying', 'oppress', 'allegiance', 'allegiances', 'allegiant', 'bowed', 'traitor', 'traitors', 'respect', 'obey', 'authority', 'obeyed', 'deference', 'reverence', 'respecting', 'obeying', 'tradition', 'adhere', 'obeys', 'revere', 'govern', 'comply', 'respectful', 'honor', 'adhered', 'dictates', 'forbid', 'dominion', 'governed', 'obedient', 'reveres', 'adhering', 'governs', 'governing', 'respected', 'respectfully', 'honorable', 'dictate', 'commandments', 'commandment', 'venerate', 'politeness', 'respects', 'obedience', 'divine right', 'forbids', 'permission', 'veneration', 'hierarchy', 'forbade', 'honoring', 'proper', 'venerated', 'stature', 'acquiesce', 'adherence', 'deferential', 'leadership', 'punish', 'forbidding', 'revered', 'filial piety', 'patriarchs', 'decree', 'coerce', 'dominions', 'dictating', 'venerating', 'wear the crown', 'venerates', 'institution', 'monarchical', 'servant', 'decrees', 'permit', 'do as one says', 'supervise', 'duty', 'compliance', 'lionize', 'supervision', 'take orders', 'take up arms', 'duties', 'dictated', 'elders', 'emperors', 'commands', 'acquiesced', 'emperor', 'adheres', 'servants', 'regulations', 'covenant', 'hierarchical', 'subordinate', 'policing', 'decreeing', 'acquiesces', 'authorizing', 'permits', 'matriarchal', 'authorizes', 'control', 'command', 'subordinating', 'hierarchies', 'reverential', 'deferentially', 'punishes', 'patriarch', 'empires', 'honored', 'traditional', 'subordination', 'punished', 'order', 'social order', 'monarchs', 'ruling', 'lead by example', 'authorities', 'guiding', 'presidents', 'slavishly', 'patriarchy', 'subordinates', 'supervisers', 'bow before', 'fathers', 'bow down', 'institutions', 'coersion', 'governors', 'commanded', 'police', 'authorize', 'bullys', 'acquiescing', 'empire', 'mentor', 'chiefs', 'monarchies', 'honors', 'preside over', 'acquiescent', 'bowing', 'oligarchy', 'willing', 'polite', 'supervising', 'pecking order', 'compliantly', 'bishops', 'monarch', 'slaves', 'punishments', 'authorized', 'compliant', 'dutiful', 'father', 'punishment', 'coerces', 'toe the line', 'monarchy', 'obediently', 'elder', 'oligarchies', 'dictators', 'leaders', 'bishop', 'lorded over', 'coercing', 'protectors', 'dictator', 'punishing', 'commanding', 'coerced', 'commanders', 'punitive', 'underlings', 'master', 'subordinated', 'president', 'in charge', 'matriarchy', 'lionizing', 'slave', 'chief', 'covenants', 'commander', 'matriarch', 'authorizer', 'guide', 'ordered', 'supervised', 'captains', 'punisher', 'supervises', 'bossing', 'commandant', 'governor', 'admiral', 'top gun', 'dominate', 'arrest', 'mentored', 'ordering', 'submit', 'institutional', 'prime minister', 'lionizes', 'ranking', 'boss', 'captain', 'by the book', 'mentors', 'dominant', 'arrested', 'bossed', 'leader', 'rank', 'arresting', 'chieftain', 'prime ministers', 'regulation', 'superviser', 'dean', 'arrests', 'punishers', 'matriarchs', 'controlling', 'managerial', 'bosses', 'ranks', 'controls', 'dictation', 'guides', 'oligarchs', 'principals', 'top dog', 'admirals', 'caste', 'captaining', 'queen', 'mentoring', 'elderly', 'castes', 'governess', 'captained', 'principal', 'submission', 'dominated', 'corporate ladders', 'queens', 'underling', 'corporate ladder', 'fathered', 'dominates', 'dominating', 'presidential', 'oligarch', 'controlled', 'submits', 'submitting', 'head honcho', 'commandingly', 'vice president', 'slaving', 'fathering', 'slaved', 'managers', 'forbiddingly', 'controllers', 'submitted', 'ringleaders', 'ringleader', 'controller', 'ranked', 'manager', 'prime ministerial', 'submissions', 'ceo', 'punishingly', 'submitter', 'submitters'], 'vice': ['treason', 'treachery', 'rebellion', 'rebel', 'treacherous', 'rebels', 'rebellions', 'disrespect', 'disobey', 'disobedience', 'anarchy', 'chaos', 'subversion', 'subvert', 'lawlessness', 'subverting', 'disrespecting', 'sedition', 'overthrow', 'insurrection', 'transgress', 'dissent', 'dishonor', 'dissention', 'disrespects', 'bedlam', 'rebelling', 'misrule', 'transgression', 'insurrectional', 'pandemonium', 'mutiny', 'mutinies', 'misruling', 'disobedient', 'subverted', 'transgresses', 'transgressed', 'disarray', 'misruled', 'rioting', 'lawless', 'transgressing', 'illegality', 'overthrowing', 'dishonorable', 'dishonoring', 'rebelled', 'riot', 'dishonouring', 'disrespected', 'permissiveness', 'refuser', 'unruly', 'subverts', 'unlawfulness', 'overthrown', 'anarchistic', 'dishonours', 'riots', 'refuse', 'chaotic', 'nonconformity', 'dissenters', 'uprising', 'insurrections', 'rioters', 'disordering', 'insubordinate', 'mutinied', 'insurrectionist', 'unlawful', 'nonconformists', 'uprisings', 'dishonors', 'tumult', 'overthrew', 'overthrows', 'rabble rousers', 'renegade', 'impolite', 'renegades', 'rabble rousing', 'dishonored', 'illegal', 'rioter', 'mutinous', 'disarrayed', 'dissidents', 'anarchists', 'raise hell', 'disorder', 'refusers', 'permissive', 'anarchist', 'dissident', 'raises hell', 'disordered', 'overpower', 'rabble rouser', 'raising hell', 'unathorized', 'refusing', 'refuses', 'rioted', 'orders', 'dissenter', 'chaotically', 'nonconformist', 'illegals', 'unlawfully', 'dissents', 'traditions', 'dissenting', 'overpowers', 'trouble maker', 'refused', 'rock the boat', 'overpowering', 'tumultuous', 'overpowered', 'dissented', 'nonconforming']}, 'sanctity': {'virtue': ['communion', 'nobility', 'nobles', 'noble', 'worship', 'worships', 'pope', 'sanctity', 'sacred', 'sacredness', 'purity', 'wholesome', 'pureness', 'wholesomeness', 'holiness', 'dignity', 'godly', 'piety', 'sanctify', 'chastity', 'undefiled', 'holy', 'sacrosanct', 'pious', 'righteousness', 'dignities', 'sanctified', 'godliness', 'spirituality', 'chaste', 'sanctifies', 'righteous', 'divine', 'religious', 'biblical', 'spiritual', 'deity', 'sanctifying', 'modesty', 'decency', 'scriptures', 'religion', 'hallow', 'soul', 'hallowed', 'deism', 'pristine', 'exalted', 'hallowing', 'eternal', 'holy cross', 'deities', 'faith', 'unadulterated', 'scripture', 'wholesomely', 'divinities', 'virgin', 'god', 'catholicism', 'saintly', 'saintliness', 'godess', 'religiosity', 'purify', 'koranic', 'pure', 'holy crosses', 'exalt', 'virginity', 'divinity', 'consecrates', 'heaven', 'virginal', 'devout', 'dignified', 'tabernacle', 'exalts', 'buddhas', 'souls', 'temple', 'unsullied', 'heavenly', 'cleanliness', 'abstinance', 'spotlessness', 'talmudic', 'deists', 'gospels', 'prophets', 'religions', 'temples', 'buddhist', 'godesses', 'saints', 'temperance', 'celibacy', 'consecrated', 'priestly', 'bless', 'marriage', 'prophet', 'exalting', 'unchaste', 'supernatural', 'eternally', 'purification', 'apostles', 'monastic', 'purified', 'gods', 'celibate', 'christians', 'theological', 'monasticism', 'unspoiled', 'sterility', 'christian', 'buddha', 'deist', 'prophetic', 'saint', 'righteously', 'apostle', 'prayer', 'faiths', 'shrine', 'purifying', 'virgins', 'glorious', 'dignifies', 'atonement', 'deification', 'orthodoxy', 'hallows', 'enshrining', 'nunneries', 'church', 'religiously', 'blessings', 'consecrate', 'gospel', 'pray', 'beatifying', 'yogis', 'theology', 'purifies', 'orthodox', 'untainted', 'torah', 'faithfully', 'catholic', 'heavens', 'yogi', 'consecrating', 'blessed', 'faithful', 'koran', 'abstinence', 'jesus', 'monastery', 'purities', 'consecration', 'catholics', 'prayers', 'prayed', 'sterile', 'blesses', 'enshrined', 'torahs', 'organic', 'bible', 'glory', 'allah', 'glories', 'priests', 'dignifying', 'enshrine', 'mosques', 'spotlessly', 'prude', 'reverend', 'soulful', 'deify', 'christ', 'cathedrals', 'churches', 'cathedral', 'dignify', 'monasteries', 'raw', 'enshrines', 'refinement', 'nuns', 'monks', 'gloriously', 'almighty', 'marring', 'repent', 'prays', 'clean', 'orthodoxies', 'exterminates', 'rabbis', 'spotless', 'bibles', 'mosque', 'immaculate', 'organics', 'purifier', 'foods', 'lord', 'praying', 'repenting', 'marry', 'elevating', 'marrying', 'immaculately', 'rabbi', 'nunnery', 'priest', 'food', 'bloodiness', 'marries', 'synagogues', 'synagogue', 'refined', 'repents', 'angel', 'blessing', 'monk', 'rabbinical', 'organically', 'nun', 'prophetically', 'blood', 'repented', 'pastor', 'purifiers', 'lords', 'bloody', 'untouched', 'cleaning', 'exterminating', 'exterminated', 'imam', 'higher power', 'cleaners', 'married', 'beatification', 'beatify', 'extermination', 'exterminate', 'cleaner', 'body', 'immune', 'atoning', 'imams', 'cleaned', 'atones', 'mary', 'refines', 'cleans', 'atone', 'immunities', 'immunity', 'stainless', 'refining', 'refine', 'atoned', 'exterminator', 'exterminators'], 'vice': ['heretic', 'apostate', 'heresy', 'heretics', 'apostates', 'heresies', 'heretical', 'impurity', 'degradation', 'depravity', 'desecrate', 'desecration', 'repulsiveness', 'degrading', 'decay', 'filth', 'depravities', 'defile', 'sin', 'fornication', 'repulsive', 'depraved', 'impiety', 'degrade', 'repugnance', 'impure', 'degraded', 'desecrations', 'sinfulness', 'impurities', 'indecencies', 'defiled', 'defiles', 'uncleanliness', 'damnation', 'debauchery', 'impious', 'sinful', 'necrophiliacs', 'desecrates', 'sleaziness', 'desecrating', 'desecrated', 'grossness', 'contaminates', 'sinning', 'promiscuity', 'befouls', 'rottenness', 'hedonism', 'revolting', 'repugnant', 'godless', 'scum', 'befoul', 'satanic', 'sluttiness', 'disgusting', 'pestilence', 'debased', 'trashiness', 'sins', 'degradingly', 'corrupting', 'deprave', 'perverted', 'debase', 'fornicating', 'degraders', 'defiling', 'slime', 'horrors', 'repugnantly', 'defiler', 'deviants', 'degrades', 'corrupts', 'debasing', 'perverts', 'parasitic', 'disgusts', 'deflowering', 'hedonistic', 'deviant', 'scummy', 'horrifying', 'necrophilia', 'contamination', 'rot', 'stain', 'contaminating', 'contaminants', 'dirtying', 'debases', 'contaminate', 'abhor', 'sleaze', 'staining', 'defilers', 'harlot', 'plagues', 'sullies', 'fornicators', 'vermin', 'befouling', 'incest', 'trashy', 'excreting', 'deforms', 'abhored', 'decayed', 'whores', 'deformities', 'perverse', 'adultery', 'fornicate', 'excrement', 'harlots', 'decaying', 'fornicator', 'unclean', 'nauseating', 'sully', 'satan', 'damns', 'satanically', 'sinned', 'sinners', 'adulterous', 'repulses', 'corruption', 'tainting', 'deformity', 'necrophiliac', 'decays', 'corrupted', 'deforming', 'contaminant', 'disgust', 'tarnishes', 'hell', 'filthy', 'taint', 'horrific', 'fecal', 'dirtied', 'flesh', 'stained', 'deform', 'putrid', 'scatalogical', 'dirties', 'whoring', 'cocksucker', 'plague', 'adulterers', 'excretes', 'infesting', 'slimy', 'excrete', 'scuzz', 'horror', 'tarnish', 'sexuality', 'parasite', 'obscenity', 'deformed', 'adulterer', 'befouled', 'muck', 'corpses', 'soiled', 'infest', 'incestuously', 'incestuous', 'fucker', 'devil', 'parasites', 'stains', 'skanks', 'corpse', 'whore', 'lepers', 'curses', 'corrupt', 'pathogens', 'diseased', 'deflower', 'hedonists', 'sinner', 'debaucherous', 'fester', 'hedonist', 'sleazy', 'fucks', 'promiscuous', 'cursed', 'curse', 'cocksuckers', 'lewdness', 'slutty', 'infests', 'festers', 'pervert', 'fuck', 'skanky', 'dirty', 'mucky', 'puke', 'alcoholism', 'feces', 'sullied', 'disgustingly', 'sexual', 'cunt', 'taints', 'profane', 'fucking', 'tarnishing', 'fornicated', 'mar', 'shitting', 'slut', 'obscene', 'barf', 'rotten', 'disgusted', 'cunts', 'waste', 'parasitically', 'sinfully', 'wastes', 'vomit', 'pathogen', 'rats', 'pathogenic', 'indecent', 'infect', 'leper', 'indecently', 'shit', 'abhors', 'skank', 'infestation', 'deflowered', 'leprosy', 'diseases', 'dirt', 'cursing', 'tarnishment', 'disease', 'prostitution', 'infested', 'sluts', 'fuckers', 'profanity', 'addiction', 'contaminated', 'scuzzy', 'infectiousness', 'indecency', 'vomitted', 'germ', 'prostituting', 'excreted', 'rubbish', 'fucked', 'sodomy', 'untouchables', 'epidemics', 'swear', 'shits', 'whorehouses', 'pigsty', 'germs', 'prostituted', 'mud', 'dung', 'epidemic', 'rat', 'douchebag', 'perversely', 'pukes', 'puking', 'prostitutes', 'barfs', 'slutting', 'trashing', 'whored', 'douchebags', 'infection', 'shite', 'spoil', 'gross', 'repulsed', 'pus', 'festering', 'cockroaches', 'tainted', 'contagion', 'barfed', 'infects', 'damned', 'addictions', 'shitty', 'skanking', 'trash', 'whorehouse', 'phlegm', 'moldy', 'plaguing', 'shat', 'drugged', 'garbage', 'infecting', 'pandemics', 'viruses', 'nauseated', 'cockroach', 'puked', 'drugging', 'manure', 'mucking', 'lewd', 'alcoholics', 'gangrenous', 'barfing', 'gangrene', 'shitter', 'shittier', 'tarnished', 'cock', 'vomits', 'hookers', 'damn', 'addict', 'alcoholic', 'nausea', 'swearing', 'vomitting', 'skanked', 'infections', 'foul', 'prostitute', 'risque', 'lice', 'gonorrhea', 'wasting', 'profanities', 'divorces', 'crappy', 'spreading', 'wasters', 'addicting', 'trashed', 'addicts', 'scabies', 'swore', 'nauseous', 'phlegmatically', 'spoiling', 'nauseatingly', 'drugs', 'virus', 'waster', 'untouchable', 'addicted', 'damning', 'pandemic', 'hooker', 'bm', 'infected', 'festered', 'marred', 'phlegmatic', 'divorce', 'viral', 'contagiously', 'plagued', 'repulsing', 'swears', 'drug', 'spoiled', 'cum', 'divorcing', 'wasted', 'divorced', 'contagious']}}


def read_json(filename):
    with open(filename, 'r',encoding='utf-8') as file:
        return json.load(file)

def word_frequency_dict(input_text):
    try:
        nlp = spacy.load("en_core_web_sm")
    except IOError:
        subprocess.popen(['python', '-m' ,'spacy' ,'download', 'en_core_web_sm'])
        nlp = spacy.load("en_core_web_sm")
    #nlp = spacy.load("en_core_web_sm")
    doc = nlp(input_text)
    words = [token.text for token in doc if token.is_stop != True and token.is_punct != True]
    word_freq = Counter(words)
    c = dict(word_freq)
    return c

def count_keywords(source_dictionary):
    output_dict = {'care':{'vice':{}, 'virtue':{}}, 'fairness':{'vice':{}, 'virtue':{}}, 'loyalty':{'vice':{}, 'virtue':{}}, 'authority':{'vice':{}, 'virtue':{}}, 'sanctity':{'vice':{}, 'virtue':{}}}
    lex = read_json(moral_foundations_dictionary)
    for item in lex.keys():
        good = [(item, source_dictionary[item]) for item in lex[item]['virtue'] if item in source_dictionary]
        bad = [(item, source_dictionary[item]) for item in lex[item]['vice'] if item in source_dictionary] 
        good_changed = {k:v for (k,v) in good}
        bad_changed = {k:v for (k,v) in bad}
        output_dict[item]['virtue'] = good_changed
        output_dict[item]['vice'] = bad_changed
    return output_dict



def read_file(filename):
    """
    Reads in a file as utf-8.
    :param filename: Filepath to the file to be read.
    """
    with open(filename, 'r',encoding='utf-8') as file:
        return file.read()

def moralize(input_text, output_format='pydict'):
    """
    Takes input text and returns format as either a Python dictionary or JSON object.
    :param input_text: Text you want to analyze.
    :param output_format: defaults to Python dictionary, enter 'json' for output in a JSON object.po
    """
    analyzed_text = word_frequency_dict(input_text)
    output_format = output_format.lower()
    if output_format == 'json':
        result = count_keywords(analyzed_text)
        return json.dumps(result)
    else:
        return count_keywords(analyzed_text, output_format)




